[next] telepathy-glib: rename tp_dbus_tube_channel_dup_parameters_vardict( )

Guillaume Desmottes gdesmott at kemper.freedesktop.org
Thu Feb 27 06:07:35 PST 2014


Module: telepathy-glib
Branch: next
Commit: 6a2bb896b5ee410c29433d6944693384987a5736
URL:    http://cgit.freedesktop.org/telepathy/telepathy-glib/commit/?id=6a2bb896b5ee410c29433d6944693384987a5736

Author: Guillaume Desmottes <guillaume.desmottes at collabora.co.uk>
Date:   Tue Feb 18 18:16:51 2014 +0100

rename tp_dbus_tube_channel_dup_parameters_vardict()

---

 docs/reference/telepathy-glib/telepathy-glib-sections.txt |    2 +-
 telepathy-glib/dbus-tube-channel.c                        |    8 ++++----
 telepathy-glib/dbus-tube-channel.h                        |    2 +-
 tests/dbus/dbus-tube.c                                    |    6 +++---
 4 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/docs/reference/telepathy-glib/telepathy-glib-sections.txt b/docs/reference/telepathy-glib/telepathy-glib-sections.txt
index 28c4a38..82b768b 100644
--- a/docs/reference/telepathy-glib/telepathy-glib-sections.txt
+++ b/docs/reference/telepathy-glib/telepathy-glib-sections.txt
@@ -5192,7 +5192,7 @@ TpStreamTubeConnectionPrivate
 TpDBusTubeChannel
 TpDBusTubeChannelClass
 TP_DBUS_TUBE_CHANNEL_FEATURE_CORE
-tp_dbus_tube_channel_dup_parameters_vardict
+tp_dbus_tube_channel_dup_parameters
 tp_dbus_tube_channel_get_service_name
 tp_dbus_tube_channel_offer_async
 tp_dbus_tube_channel_offer_finish
diff --git a/telepathy-glib/dbus-tube-channel.h b/telepathy-glib/dbus-tube-channel.h
index 814ed55..63d6404 100644
--- a/telepathy-glib/dbus-tube-channel.h
+++ b/telepathy-glib/dbus-tube-channel.h
@@ -67,7 +67,7 @@ _TP_AVAILABLE_IN_0_18
 const gchar * tp_dbus_tube_channel_get_service_name (TpDBusTubeChannel *self);
 
 _TP_AVAILABLE_IN_0_20
-GVariant * tp_dbus_tube_channel_dup_parameters_vardict (TpDBusTubeChannel *self);
+GVariant * tp_dbus_tube_channel_dup_parameters (TpDBusTubeChannel *self);
 
 /* Outgoing tube methods */
 
diff --git a/tests/dbus/dbus-tube.c b/tests/dbus/dbus-tube.c
index b29c1f3..e1f8d05 100644
--- a/tests/dbus/dbus-tube.c
+++ b/tests/dbus/dbus-tube.c
@@ -195,7 +195,7 @@ test_properties (Test *test,
   g_free (service);
 
   /* Parameters */
-  parameters_vardict = tp_dbus_tube_channel_dup_parameters_vardict (
+  parameters_vardict = tp_dbus_tube_channel_dup_parameters (
       test->tube);
   /* NULL as the tube has not be offered yet */
   g_assert (parameters_vardict == NULL);
@@ -204,7 +204,7 @@ test_properties (Test *test,
   create_tube_service (test, FALSE, FALSE);
 
   /* Parameters */
-  parameters_vardict = tp_dbus_tube_channel_dup_parameters_vardict (
+  parameters_vardict = tp_dbus_tube_channel_dup_parameters (
       test->tube);
   check_parameters_vardict (parameters_vardict);
 
@@ -368,7 +368,7 @@ test_offer (Test *test,
   g_main_loop_run (test->mainloop);
   g_assert_no_error (test->error);
 
-  variant = tp_dbus_tube_channel_dup_parameters_vardict (test->tube);
+  variant = tp_dbus_tube_channel_dup_parameters (test->tube);
   check_parameters_vardict (variant);
   g_variant_unref (variant);
 



More information about the telepathy-commits mailing list
diff --git a/telepathy-glib/dbus-tube-channel.c b/telepathy-glib/dbus-tube-channel.c
index f53c2f9..a171079 100644
--- a/telepathy-glib/dbus-tube-channel.c
+++ b/telepathy-glib/dbus-tube-channel.c
@@ -156,7 +156,7 @@ tp_dbus_tube_channel_get_property (GObject *object,
 
       case PROP_PARAMETERS_VARDICT:
         g_value_take_variant (value,
-            tp_dbus_tube_channel_dup_parameters_vardict (self));
+            tp_dbus_tube_channel_dup_parameters (self));
         break;
 
       default:
@@ -438,7 +438,7 @@ tp_dbus_tube_channel_class_init (TpDBusTubeChannelClass *klass)
    * Will be %NULL for outgoing tubes until the tube has been offered.
    *
    * In high-level language bindings, use
    * tp_dbus_tube_channel_dup_parameters_vardict() to get the same information
    * in a more convenient format.
    *
    * Since: 0.18.0
@@ -522,7 +522,7 @@ tp_dbus_tube_channel_get_service_name (TpDBusTubeChannel *self)
 }
 
 /**
- * tp_dbus_tube_channel_dup_parameters_vardict:
+ * tp_dbus_tube_channel_dup_parameters:
  * @self: a #TpDBusTubeChannel
  *
  * Return the parameters of the dbus-tube channel in a variant of
@@ -541,7 +541,7 @@ tp_dbus_tube_channel_get_service_name (TpDBusTubeChannel *self)
  * Since: 0.19.10
  */
 GVariant *
-tp_dbus_tube_channel_dup_parameters_vardict (TpDBusTubeChannel *self)
+tp_dbus_tube_channel_dup_parameters (TpDBusTubeChannel *self)
 {
   g_return_val_if_fail (TP_IS_DBUS_TUBE_CHANNEL (self), NULL);
 
@@ -438,7 +438,7 @@ tp_dbus_tube_channel_class_init (TpDBusTubeChannelClass *klass)
    *
    * In high-level language bindings, use
-   * tp_dbus_tube_channel_dup_parameters_vardict() to get the same information
+   * tp_dbus_tube_channel_dup_parameters() to get the same information
    * in a more convenient format.
    *